@@ -217,7 +217,7 @@ class Normalizer():
         nb4 = r'4'
         nc4 = sub(na4, nb4, nc3)
         na5 = r'۵'
-        nb5 = r'5'
+        nb5 = r'۵'
         nc5 = sub(na5, nb5, nc4)
         na6 = r'۶|٦'
         nb6 = r'6'
