@@ -653,9 +653,10 @@ from .data_helper import DataHelper
 from .normalizer import Normalizer
 import json
 
-class  FindStems():
 
-    def __init__(self,config_file):
+class FindStems():
+
+    def __init__(self, config_file, double_postfix_joint):
 
         self.dir_path = os.path.dirname(os.path.realpath(__file__)) + "/"
 
@@ -670,7 +671,6 @@ class  FindStems():
         self.mokasar_noun_path = self.dir_path + "resource/stemmer/mokasar.txt"
         self.data_helper = DataHelper()
 
-
         if (os.path.isfile(self.noun_lex_path) and os.path.isfile(self.verb_lex_path)
                 and os.path.isfile(self.verb_tense_map_path) and os.path.isfile(self.irregular_nouns_path)):
             self.noun_lexicon = self.data_helper.load_var(self.noun_lex_path)
@@ -709,9 +709,9 @@ class  FindStems():
             for el in pasvandFile_content:
                 self.postfix_list.add(el.strip())
 
-
         with open(config_file) as f:
             self.affix_list = json.load(f)
+        self.double_postfix_joint = double_postfix_joint
 
     def select_candidate(self, candidate_list, lexicon_set=None):
         length = 1000
@@ -771,7 +771,6 @@ class  FindStems():
                 else:
                     tmp = word
 
-
         return last_el, candidateStem
 
     def map_irregular_noun(self, word):
@@ -872,7 +871,6 @@ class  FindStems():
                     stem = word
                 return word
 
-
         # if word is a verb
         if word_pos is None or word_pos == "V":
 
@@ -987,7 +985,6 @@ class  FindStems():
                                 output += i + "\u200c"
                             output += new_word
                             for i in postfix_tmp:
-
                                 output += i
 
                             return output
@@ -1222,7 +1219,6 @@ class  FindStems():
 
             postfix, candidate_list = self.remove_postfixes(word, self.affix_list["prop_postfix_all"])
 
-
             postfix_tmp.append(postfix)
             postfix_tmp = list(filter(('').__ne__, postfix_tmp))
             if len(candidate_list) > 0:
@@ -1246,8 +1242,6 @@ class  FindStems():
             #
             #     return text + ' '
 
-
-
             postfix, candidate_list = self.remove_postfixes(new_word, self.affix_list["plural_postfix_all"])
             postfix_tmp.append(postfix)
             postfix_tmp = list(filter(('').__ne__, postfix_tmp))
@@ -1265,8 +1259,7 @@ class  FindStems():
             new_word, ge = self.postfix_g(new_word)
             pos = ge + pos
 
-
-            if new_word in self.noun_lexicon  and word != new_word:
+            if new_word in self.noun_lexicon and word != new_word:
 
                 if pre != "":
                     if pre in self.affix_list["prefix_joint"]:
@@ -1276,15 +1269,24 @@ class  FindStems():
                 else:
                     text = ""
                 text += self.map_irregular_noun(new_word)
-                if pos in self.affix_list["postfix_joint"]+self.affix_list["irregular_postfix_joint"]:
+                if pos in self.affix_list["postfix_joint"] + self.affix_list["irregular_postfix_joint"]:
                     text += pos
                 elif pos != "":
-                    text = text + "\u200c" + pos
+                    text = text + " " + pos
                 for i in reversed(postfix_tmp):
-                    if i in self.affix_list["postfix_joint"]+self.affix_list["irregular_postfix_joint"]:
+                    if self.double_postfix_joint and len(postfix_tmp) == 2 and postfix_tmp[1] in self.affix_list[
+                        "plural_postfix_all"] and \
+                            postfix_tmp[0] in self.affix_list["prop_postfix_all"]:
+                        if postfix_tmp[1] in self.affix_list["postfix_joint"]:
+                            text += postfix_tmp[1] + "\u200c" + postfix_tmp[0]
+                        else:
+                            text += ' ' + postfix_tmp[1] + "\u200c" + postfix_tmp[0]
+
+                        break
+                    if i in self.affix_list["postfix_joint"] + self.affix_list["irregular_postfix_joint"]:
                         text += i
                     else:
-                        text += '\u200c' + i
+                        text += ' ' + i
 
                 return text + ' '
             #
@@ -1293,7 +1295,7 @@ class  FindStems():
 
             if new_word in self.noun_lexicon:
                 text = ''
-                text += self.map_irregular_noun(new_word) + '\u200c' + pos
+                text += self.map_irregular_noun(new_word) + ' ' + pos
                 return text
 
             postfix, candidate_list = self.remove_postfixes(new_word, ["گ"])
@@ -1305,10 +1307,10 @@ class  FindStems():
 
                 if new_word in self.noun_lexicon:
 
-                    if postfix in self.affix_list["postfix_joint"]+self.affix_list["irregular_postfix_joint"]:
-                        return self.map_irregular_noun(new_word)+postfix_tmp
+                    if postfix in self.affix_list["postfix_joint"] + self.affix_list["irregular_postfix_joint"]:
+                        return self.map_irregular_noun(new_word) + postfix_tmp
                     else:
-                        return self.map_irregular_noun(new_word)+"\u200c"+postfix_tmp
+                        return self.map_irregular_noun(new_word) + " " + postfix_tmp
 
             else:
                 new_word = stem_candidate
@@ -1329,11 +1331,10 @@ class  FindStems():
             else:
                 new_word = stem_candidate
 
-
             if new_word in self.noun_lexicon and len(prefix_tmp) != 0:
 
-                text = str(prefix_tmp[0]) + '\u200c'
-                text += self.map_irregular_noun(new_word) + '\u200c'
+                text = str(prefix_tmp[0]) + ' '
+                text += self.map_irregular_noun(new_word) + ' '
                 for i in reversed(postfix_tmp):
                     text += i + ' '
 
@@ -1355,7 +1356,6 @@ class  FindStems():
                     else:
                         return prefix1 + '\u200c' + new_word
 
-
         # split  "می/نمی" from start of  all words
         # prefix1, candidate_list = self.remove_prefixes(word, self.affix_list["slang_verbs_prefix"])
         # print(candidate_list)
